<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <source>Name:</source>
        <translation>Emër:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="114"/>
        <source>Command:</source>
        <translation>Urdhër:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="116"/>
        <source>Shortcuts:</source>
        <translation>Shkurtore:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="127"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="128"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="205"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="211"/>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="154"/>
        <source>Add Command</source>
        <translation>Shtoni Urdhër</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="160"/>
        <source>Edit Command</source>
        <translation>Përpunoni Urdhër</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="170"/>
        <source>Delete Command</source>
        <translation>Fshije Urdhrin</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="191"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="193"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Shtoje</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="195"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Ruaje</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="372"/>
        <source>Please enter a name</source>
        <translation>Ju lutemi, jepni një emër</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="386"/>
        <source>Please enter a command</source>
        <translation>Ju lutemi, jepni një urdhër</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="436"/>
        <source>The name already exists,</source>
        <translation>Emri ekziston tashmë,</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="437"/>
        <source>please input another one.</source>
        <translation>ju lutemi, jepni një tjetër.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="618"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="212"/>
        <source>Add Command</source>
        <translation>Shtoni Urdhër</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="216"/>
        <source>No commands yet</source>
        <translation>Ende pa urdhra</translation>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="50"/>
        <source>Custom commands</source>
        <translation>Urdhra vetjakë</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="146"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="236"/>
        <source>Custom Theme</source>
        <translation>Temë Vetjake</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="260"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="264"/>
        <source>Light</source>
        <translation>E çelët</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="269"/>
        <source>Dark</source>
        <translation>E errët</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="323"/>
        <source>Fore color:</source>
        <translation>Ngjyrë përpara:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="330"/>
        <source>Back color:</source>
        <translation>Ngjyrë pas:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="348"/>
        <source>Prompt PS1:</source>
        <translation>Prompt PS1:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="352"/>
        <source>Prompt PS2:</source>
        <translation>Prompt PS2:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="423"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <source>Delete Server</source>
        <translation>Fshije Shërbyesin</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <location filename="../src/views/listview.cpp" line="492"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Jeni i sigurt se doni të fshihet %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="269"/>
        <location filename="../src/main/mainwindow.cpp" line="324"/>
        <source>New window</source>
        <translation>Dritare e re</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="339"/>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="755"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="757"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Mbylle</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1829"/>
        <source>Type path to download file</source>
        <translation>Shtypni shteg për shkarkim kartele</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2135"/>
        <source>Custom Theme</source>
        <translation>Temë Vetjake</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/views/listview.cpp" line="304"/>
        <location filename="../src/views/listview.cpp" line="493"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="236"/>
        <location filename="../src/common/utils.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="305"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Fshije</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="494"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="514"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close workspace</source>
        <translation>Mbylle hapësirën e punës</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="517"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close other workspaces</source>
        <translation>Mbyll hapësira të tjera pune</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1177"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation>S’u gjet dot &quot;%1&quot;, në vend të tij po niset &quot;%2&quot;. Ju lutemi, kontrolloni profilin tuaj për shellin.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1183"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation>S’u hap dot &quot;%1&quot;, s’arrihet të xhirohet</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1185"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation>S’u gjet dot &quot;%1&quot;, s’arrihet të xhirohet</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1215"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>Shfaqja e përfundimit është pezulluar nga shtypja e tasteve Ctrl+S. Shtypni Ctrl+Q që të vazhdojë.</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="132"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Tab title format</source>
        <translation>Format titulli skede</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="134"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Remote tab title format</source>
        <translation>Format titulli skede të largët</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamedlg.cpp" line="203"/>
        <location filename="../src/views/tabbar.cpp" line="504"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Rename title</source>
        <translation>Titull riemërtimi</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="498"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close tab</source>
        <translation>Mbylle skedën</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="501"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close other tabs</source>
        <translation>Mbylli skedat e tjera</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Copy on select</source>
        <translation>Kopjo kur përzgjidhet</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Cursor blink</source>
        <translation>Xixëllim kursori</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Cursor style</source>
        <translation>Stil kursori</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Scroll on keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Scroll on output</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Fshihe dritaren Quake pas humbjes së fokusit</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <location filename="../src/main/service.cpp" line="159"/>
        <source>Blur background</source>
        <translation>Turbulloje sfondin</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Use on starting</source>
        <translation>Përdore gjatë nisjes</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Font</source>
        <translation>Shkronja</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Font size</source>
        <translation>Madhësi shkronjash</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <location filename="../src/main/service.cpp" line="182"/>
        <source>Opacity</source>
        <translation>Patejdukshmëri</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Advanced</source>
        <translation>Të mëtejshme</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Scroll</source>
        <translation>Rrëshqitje</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Window</source>
        <translation>Dritare</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Basic</source>
        <translation>Elementare</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Shortcuts</source>
        <translation>Shkurtore</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/main/mainwindow.cpp" line="1671"/>
        <source>Others</source>
        <translation>Të tjera</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <location filename="../src/main/terminalapplication.cpp" line="36"/>
        <location filename="../src/main/mainwindow.cpp" line="1669"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Workspace</source>
        <translation>Hapësirë Pune</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Custom commands</source>
        <translation>Urdhra vetjakë</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Remote management</source>
        <translation>Administrim së largëti</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Default size</source>
        <translation>Madhësi parazgjedhje</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Paste</source>
        <translation>Ngjite</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Select all</source>
        <translation>Përzgjidhi krejt</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Jump to next command</source>
        <translation>Kalo te urdhri pasues</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <source>Jump to previous command</source>
        <translation>Kalo te urdhri i mëparshëm</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom in</source>
        <translation>Zmadhoje</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom out</source>
        <translation>Zvogëloje</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Close other windows</source>
        <translation>Mbylli dritaret e tjera</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Close window</source>
        <translation>Mbylle dritaren</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Horizontal split</source>
        <translation>Ndarje horizontale</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>New tab</source>
        <translation>Skedë e re</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Next tab</source>
        <translation>Skeda pasuese</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Previous tab</source>
        <translation>Skeda e mëparshme</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select left workspace</source>
        <translation>Përzgjidhni hapësirën e punës majtas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select lower workspace</source>
        <translation>Përzgjidhni hapësirën e poshtme të punës</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select right workspace</source>
        <translation>Përzgjidhni hapësirën e punës djathtas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select upper workspace</source>
        <translation>Përzgjidhni hapësirën e sipërme të punës</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Vertical split</source>
        <translation>Ndarje vertikale</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Find</source>
        <translation>Gjej</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Tab titles</source>
        <translation>Tituj skedash</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 1</source>
        <translation>Shko te skeda 1</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 2</source>
        <translation>Kalo te skeda 2</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 3</source>
        <translation>Kalo te skeda 3</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 4</source>
        <translation>Kalo te skeda 4</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 5</source>
        <translation>Kalo te skeda 5</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 6</source>
        <translation>Kalo te skeda 6</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 7</source>
        <translation>Kalo te skeda 7</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 8</source>
        <translation>Kalo te skeda 8</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 9</source>
        <translation>Kalo te skeda 9</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="155"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Çaktivizoni kontroll rrjedhe duke përdorur Ctrl+S, Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="157"/>
        <source>Shell profile</source>
        <translation>Profil shelli</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="517"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="379"/>
        <source>The name should be no more than 32 characters</source>
        <translation>Emri s’duhet të jetë më tepër se 32 shenja</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="583"/>
        <source>Select the private key file</source>
        <translation>Përzgjidhni kartelën e kyçit privat</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="587"/>
        <location filename="../src/main/mainwindow.cpp" line="1851"/>
        <location filename="../src/common/utils.cpp" line="133"/>
        <source>Select</source>
        <translation>Përzgjidhe</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="39"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>Terminali është një emulues i thelluar terminali, me hapësira pune, dritare të shumta, administrim së largëti, mënyrë Quake dhe veçori të tjera.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1667"/>
        <source>Tabs</source>
        <translation>Skeda</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1687"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation>Kaloje fokusin te ikona &quot;+&quot;</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select tab</source>
        <translation>Përzgjidhni skedë</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1775"/>
        <location filename="../src/common/utils.cpp" line="148"/>
        <source>Select file to upload</source>
        <translation>Përzgjidhni kartelë për ngarkim</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1782"/>
        <location filename="../src/common/utils.cpp" line="153"/>
        <source>Upload</source>
        <translation>Ngarkim</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1845"/>
        <location filename="../src/common/utils.cpp" line="127"/>
        <source>Select a directory to save the file</source>
        <translation>Përzgjidhni një drejtori ku të ruhet kartela</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="403"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="621"/>
        <location filename="../src/common/utils.cpp" line="254"/>
        <source>please set another one.</source>
        <translation>ju lutemi, caktoni një tjetër.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="173"/>
        <location filename="../src/common/utils.cpp" line="207"/>
        <source>Close this terminal?</source>
        <translation>Të mbyllet ky terminal?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="174"/>
        <location filename="../src/common/utils.cpp" line="208"/>
        <source>There is still a process running in this terminal. Closing the terminal will kill it.</source>
        <translation>Ka ende një proces që xhiron në këtë terminal. Mbyllja e terminalit do ta asgjësojë.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="178"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will kill all of them.</source>
        <translation>Ka ende %1 procese që xhirojnë në këtë terminal. Mbyllja e terminalit do t’i asgjësojë krejt ata.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="203"/>
        <source>Close this window?</source>
        <translation>Të mbyllet dritarja?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="184"/>
        <location filename="../src/common/utils.cpp" line="204"/>
        <source>There are still processes running in this window. Closing the window will kill all of them.</source>
        <translation>Ka ende procese që xhirojnë në këtë dritare. Mbyllja e dritares do t’i asgjësojë krejt ata.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Programs are still running in terminal</source>
        <translation>Ka ende programe që xhirojnë në terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Jeni i sigurt se doni të çinstalohet?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="234"/>
        <location filename="../src/common/utils.cpp" line="238"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>Jeni i sigurt se doni të çinstalohet ky aplikacion?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="235"/>
        <location filename="../src/common/utils.cpp" line="239"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>S’do të jeni më në gjendje të xhironi Terminal-in.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="245"/>
        <location filename="../src/common/utils.cpp" line="289"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="323"/>
        <source>Set the work directory</source>
        <translation>Caktoni drejtorinë e punës</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="326"/>
        <source>Set the window mode on starting</source>
        <translation>Caktoni mënyrë dritareje kur hapet</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="329"/>
        <source>Execute a command in the terminal</source>
        <translation>Ekzekutoni një urdhër te terminali</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Run script string in the terminal</source>
        <translation>Xhironi te terminali varg programthi</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Run in quake mode</source>
        <translation>Xhiroje nën mënyrën dridhje</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Keep terminal open when command finishes</source>
        <translation>Kur urdhri përfundon, mbaje hapur terminalin</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="201"/>
        <source>Add Server</source>
        <translation>Shtoni Shërbyes</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="205"/>
        <source>No servers yet</source>
        <translation>Ende pa shërbyes</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="90"/>
        <source>Remote management</source>
        <translation>Administrim së largëti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="216"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>Përpara se të djathtasklikoni për ngarkim dhe shkarkim kartelash, sigurohuni që urdhrat rz dhe sz janë të instaluar te shërbyesi.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="225"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="70"/>
        <source>Advanced options</source>
        <translation>Mundësi të mëtejshme</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="108"/>
        <source>Add Server</source>
        <translation>Shtoni Shërbyes</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Server name:</source>
        <translation>Emër shërbyesi:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="146"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="156"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="184"/>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="154"/>
        <source>Address:</source>
        <translation>Adresë:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="161"/>
        <source>Port:</source>
        <translation>Portë:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="182"/>
        <source>Username:</source>
        <translation>Emër përdoruesi:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>Password:</source>
        <translation>Fjalekalim:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="195"/>
        <source>Certificate:</source>
        <translation>Dëshmi:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Group:</source>
        <translation>Grup:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Path:</source>
        <translation>Shteg:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Command:</source>
        <translation>Urdhër:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Encoding:</source>
        <translation>Kodim:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="235"/>
        <source>Backspace key:</source>
        <translation>Tasti Backspace:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="241"/>
        <source>Delete key:</source>
        <translation>Fshije tastin:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="247"/>
        <source>Delete server</source>
        <translation>Fshije shërbyesin</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="261"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="262"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Shtoje</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="266"/>
        <source>Edit Server</source>
        <translation>Përpunoni Shërbyes</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="267"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Ruaje</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="511"/>
        <source>Please enter a server name</source>
        <translation>Ju lutemi, jepni një emër shërbyesi</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="524"/>
        <source>Please enter an IP address</source>
        <translation>Ju lutemi, jepni një adresë IP</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="529"/>
        <source>Please enter a port</source>
        <translation>Ju lutemi, jepni një portë</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="535"/>
        <source>Please enter a username</source>
        <translation>Ju lutemi, jepni një emër përdoruesi</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="549"/>
        <source>The server name already exists,</source>
        <translation>Emri i shërbyesit ekziston tashmë,</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="550"/>
        <source>please input another one. </source>
        <translation>ju lutemi, jepni një tjetër.</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="399"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Normal window</source>
        <translation>Dritare normale</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Split screen</source>
        <translation>Ndaje ekranin</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="283"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="292"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>Shkurtorja %1 është e pavlefshme,</translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="299"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="306"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="312"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>Shkurtorja %1 është tashmë në përdorim,</translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="60"/>
        <source>Insert</source>
        <translation>Futni</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>username: %u</source>
        <translation>emër përdoruesi: %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>username@: %U</source>
        <translation>emër_përdoruesi@: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>remote host: %h</source>
        <translation>strehë e largët: %h</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>session number: %#</source>
        <translation>numër sesionesh: %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="110"/>
        <source>title set by shell: %w</source>
        <translation>titull i caktuar nga shelli: %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>program name: %n</source>
        <translation>emër programi: %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>current directory (short): %d</source>
        <translation>drejtoria e tanishme (shkurt): %d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>current directory (long): %D</source>
        <translation>drejtoria e tanishme (gjatë): %D</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>local host: %h</source>
        <translation>strehë vendore: %h</translation>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="483"/>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="486"/>
        <source>Paste</source>
        <translation>Ngjite</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="495"/>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Open in file manager</source>
        <translation>Hape në përgjegjës kartelash</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="508"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Horizontal split</source>
        <translation>Ndarje horizontale</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="511"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Vertical split</source>
        <translation>Ndarje vertikale</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="521"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>New tab</source>
        <translation>Skedë e re</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="528"/>
        <source>Exit fullscreen</source>
        <translation>Dil nga mënyra sa krejt ekrani</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="530"/>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Find</source>
        <translation>Gjej</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="547"/>
        <source>Encoding</source>
        <translation>Kodim</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Custom commands</source>
        <translation>Urdhra vetjakë</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="551"/>
        <source>Remote management</source>
        <translation>Administrim së largëti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="555"/>
        <source>Upload file</source>
        <translation>Ngarkoni kartelë</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="556"/>
        <source>Download file</source>
        <translation>Shkarkoje kartelën</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="561"/>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="189"/>
        <location filename="../src/common/utils.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="191"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Mbylle</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="224"/>
        <location filename="../src/common/utils.cpp" line="256"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
</TS>